r"""
Crystals
========

Quickref
--------

.. TODO:: Write it!

Introductory material
---------------------

- :ref:`sage.combinat.crystals.crystals`
- The `Lie Methods and Related Combinatorics <../../../../../thematic_tutorials/lie.html>`_ thematic tutorial

Catalogs of crystals
--------------------

- :ref:`sage.combinat.crystals.catalog`

See also
--------

- The categories for crystals: :class:`Crystals`, :class:`HighestWeightCrystals`,
  :class:`FiniteCrystals`, :class:`ClassicalCrystals`, :class:`RegularCrystals`,
  :class:`~sage.categories.regular_supercrystals.RegularSuperCrystals`
  -- The categories for crystals
- :ref:`sage.combinat.root_system`
"""
